"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from opperai.types import BaseModel
from typing_extensions import TypedDict


class Syntax(str, Enum):
    LARK = "lark"
    REGEX = "regex"


class CustomFormatGrammarGrammarTypedDict(TypedDict):
    definition: str
    syntax: Syntax


class CustomFormatGrammarGrammar(BaseModel):
    definition: str

    syntax: Syntax
