"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .websearchoptionsuserlocationapproximate import (
    WebSearchOptionsUserLocationApproximate,
    WebSearchOptionsUserLocationApproximateTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class WebSearchOptionsUserLocationTypedDict(TypedDict):
    approximate: WebSearchOptionsUserLocationApproximateTypedDict
    type: Literal["approximate"]


class WebSearchOptionsUserLocation(BaseModel):
    approximate: WebSearchOptionsUserLocationApproximate

    TYPE: Annotated[
        Annotated[
            Literal["approximate"], AfterValidator(validate_const("approximate"))
        ],
        pydantic.Field(alias="type"),
    ] = "approximate"
