"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .submitfeedbackrequest import SubmitFeedbackRequest, SubmitFeedbackRequestTypedDict
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SubmitSpanFeedbackSpansSpanIDFeedbackPostRequestTypedDict(TypedDict):
    span_id: str
    r"""The ID of the span to provide feedback on"""
    submit_feedback_request: SubmitFeedbackRequestTypedDict


class SubmitSpanFeedbackSpansSpanIDFeedbackPostRequest(BaseModel):
    span_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the span to provide feedback on"""

    submit_feedback_request: Annotated[
        SubmitFeedbackRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
