"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ListFilesResponseTypedDict(TypedDict):
    id: str
    r"""The id of the file"""
    original_filename: str
    r"""The original filename"""
    size: int
    r"""The size of the file in bytes"""
    status: str
    r"""The indexing status of the file"""
    document_id: int
    r"""The id of the associated document"""
    metadata: NotRequired[Dict[str, Any]]
    r"""The metadata attached to the file"""


class ListFilesResponse(BaseModel):
    id: str
    r"""The id of the file"""

    original_filename: str
    r"""The original filename"""

    size: int
    r"""The size of the file in bytes"""

    status: str
    r"""The indexing status of the file"""

    document_id: int
    r"""The id of the associated document"""

    metadata: Optional[Dict[str, Any]] = None
    r"""The metadata attached to the file"""
