"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class FunctionCallInputTypedDict(TypedDict):
    arguments: str
    name: str


class FunctionCallInput(BaseModel):
    arguments: str

    name: str
