"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class UpdateCustomModelResponseTypedDict(TypedDict):
    id: str
    r"""The ID of the custom language model"""
    name: str
    r"""The name of the custom language model"""
    identifier: str
    r"""The identifier of the custom language model"""
    extra: NotRequired[Dict[str, Any]]
    r"""Extra metadata about the custom language model"""


class UpdateCustomModelResponse(BaseModel):
    id: str
    r"""The ID of the custom language model"""

    name: str
    r"""The name of the custom language model"""

    identifier: str
    r"""The identifier of the custom language model"""

    extra: Optional[Dict[str, Any]] = None
    r"""Extra metadata about the custom language model"""
