"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customformatgrammargrammar import (
    CustomFormatGrammarGrammar,
    CustomFormatGrammarGrammarTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class CustomFormatGrammarTypedDict(TypedDict):
    grammar: CustomFormatGrammarGrammarTypedDict
    type: Literal["grammar"]


class CustomFormatGrammar(BaseModel):
    grammar: CustomFormatGrammarGrammar

    TYPE: Annotated[
        Annotated[Literal["grammar"], AfterValidator(validate_const("grammar"))],
        pydantic.Field(alias="type"),
    ] = "grammar"
