"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openai_types_chat_chat_completion_message_custom_tool_call_param_custom import (
    OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustom,
    OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustomTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ChatCompletionMessageCustomToolCallParamTypedDict(TypedDict):
    id: str
    custom: OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustomTypedDict
    type: Literal["custom"]


class ChatCompletionMessageCustomToolCallParam(BaseModel):
    id: str

    custom: OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustom

    TYPE: Annotated[
        Annotated[Literal["custom"], AfterValidator(validate_const("custom"))],
        pydantic.Field(alias="type"),
    ] = "custom"
