"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from opperai.errors import OpperError
from opperai.types import BaseModel
from typing import Any, Optional


class ErrorData(BaseModel):
    type: str

    message: str

    detail: Any


@dataclass(unsafe_hash=True)
class Error(OpperError):
    data: ErrorData = field(hash=False)

    def __init__(
        self, data: ErrorData, raw_response: httpx.Response, body: Optional[str] = None
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
