"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .registerfileuploadrequest import (
    RegisterFileUploadRequest,
    RegisterFileUploadRequestTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequestTypedDict(
    TypedDict
):
    knowledge_base_id: str
    r"""The id of the knowledge base to register the file for"""
    register_file_upload_request: RegisterFileUploadRequestTypedDict


class RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequest(BaseModel):
    knowledge_base_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the knowledge base to register the file for"""

    register_file_upload_request: Annotated[
        RegisterFileUploadRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
