"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class MetaTypedDict(TypedDict):
    total_count: int
    r"""Total number of items in the collection"""


class Meta(BaseModel):
    total_count: int
    r"""Total number of items in the collection"""
