"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class SubmitFeedbackResponseTypedDict(TypedDict):
    span_id: str
    r"""The ID of the span"""
    score: float
    r"""The feedback score that was submitted"""
    example_saved: bool
    r"""Whether the example was saved to the dataset"""


class SubmitFeedbackResponse(BaseModel):
    span_id: str
    r"""The ID of the span"""

    score: float
    r"""The feedback score that was submitted"""

    example_saved: bool
    r"""Whether the example was saved to the dataset"""
