"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class DeleteKnowledgeBaseResponseTypedDict(TypedDict):
    deleted_count: int
    r"""The number of documents deleted"""


class DeleteKnowledgeBaseResponse(BaseModel):
    deleted_count: int
    r"""The number of documents deleted"""
