"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from opperai.types import BaseModel
from typing import Any, Dict, List
from typing_extensions import TypedDict


class Mode(str, Enum):
    AUTO = "auto"
    REQUIRED = "required"


class ChatCompletionAllowedToolsParamTypedDict(TypedDict):
    mode: Mode
    tools: List[Dict[str, Any]]


class ChatCompletionAllowedToolsParam(BaseModel):
    mode: Mode

    tools: List[Dict[str, Any]]
