"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from opperai.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class InputAudioFormat(str, Enum):
    WAV = "wav"
    MP3 = "mp3"


class InputAudioTypedDict(TypedDict):
    data: str
    format_: InputAudioFormat


class InputAudio(BaseModel):
    data: str

    format_: Annotated[InputAudioFormat, pydantic.Field(alias="format")]
