"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .body_upload_file_knowledge_knowledge_base_id_upload_post import (
    BodyUploadFileKnowledgeKnowledgeBaseIDUploadPost,
    BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UploadFileKnowledgeKnowledgeBaseIDUploadPostRequestTypedDict(TypedDict):
    knowledge_base_id: str
    r"""The id of the knowledge base to upload the file to"""
    body_upload_file_knowledge_knowledge_base_id_upload_post: (
        BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostTypedDict
    )


class UploadFileKnowledgeKnowledgeBaseIDUploadPostRequest(BaseModel):
    knowledge_base_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the knowledge base to upload the file to"""

    body_upload_file_knowledge_knowledge_base_id_upload_post: Annotated[
        BodyUploadFileKnowledgeKnowledgeBaseIDUploadPost,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]
