"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class RegisterFileUploadResponseTypedDict(TypedDict):
    id: str
    key: str
    original_filename: str
    document_id: int
    metadata: NotRequired[Dict[str, Any]]


class RegisterFileUploadResponse(BaseModel):
    id: str

    key: str

    original_filename: str

    document_id: int

    metadata: Optional[Dict[str, Any]] = None
