"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class GetUploadURLResponseTypedDict(TypedDict):
    url: str
    fields: Dict[str, Any]
    id: str


class GetUploadURLResponse(BaseModel):
    url: str

    fields: Dict[str, Any]

    id: str
