"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class FileDownloadURLResponseTypedDict(TypedDict):
    url: str
    r"""Presigned URL to download the file"""
    expires_in: int
    r"""Number of seconds until the URL expires"""


class FileDownloadURLResponse(BaseModel):
    url: str
    r"""Presigned URL to download the file"""

    expires_in: int
    r"""Number of seconds until the URL expires"""
