"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FileFileTypedDict(TypedDict):
    file_data: NotRequired[str]
    file_id: NotRequired[str]
    filename: NotRequired[str]


class FileFile(BaseModel):
    file_data: Optional[str] = None

    file_id: Optional[str] = None

    filename: Optional[str] = None
