"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rerankdocument import RerankDocument, RerankDocumentTypedDict
from opperai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class RerankRequestModelTypedDict(TypedDict):
    r"""Request model for reranking."""

    query: str
    r"""The search query to rank documents against"""
    documents: List[RerankDocumentTypedDict]
    r"""List of documents to rerank"""
    model: str
    r"""The reranking model to use"""
    top_k: NotRequired[Nullable[int]]
    r"""Number of top documents to return. Defaults to all documents."""
    return_documents: NotRequired[bool]
    r"""Whether to return document content in the response"""
    max_chunks_per_doc: NotRequired[Nullable[int]]
    r"""Maximum number of chunks per document"""


class RerankRequestModel(BaseModel):
    r"""Request model for reranking."""

    query: str
    r"""The search query to rank documents against"""

    documents: List[RerankDocument]
    r"""List of documents to rerank"""

    model: str
    r"""The reranking model to use"""

    top_k: OptionalNullable[int] = UNSET
    r"""Number of top documents to return. Defaults to all documents."""

    return_documents: Optional[bool] = True
    r"""Whether to return document content in the response"""

    max_chunks_per_doc: OptionalNullable[int] = UNSET
    r"""Maximum number of chunks per document"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["top_k", "return_documents", "max_chunks_per_doc"]
        nullable_fields = ["top_k", "max_chunks_per_doc"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
