"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .model import Model, ModelTypedDict
from typing import Any, Dict, List, Union
from typing_extensions import TypeAliasType


TModel1TypedDict = TypeAliasType(
    "TModel1TypedDict", Union[ModelTypedDict, str, Dict[str, Any]]
)


TModel1 = TypeAliasType("TModel1", Union[Model, str, Dict[str, Any]])


TModelTypedDict = TypeAliasType(
    "TModelTypedDict",
    Union[ModelTypedDict, str, Dict[str, Any], List[TModel1TypedDict]],
)


TModel = TypeAliasType("TModel", Union[Model, str, Dict[str, Any], List[TModel1]])
