"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequestTypedDict(TypedDict):
    knowledge_base_id: str
    r"""The id of the knowledge base to get the upload URL for"""
    filename: str
    r"""The filename of the file to upload"""


class GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequest(BaseModel):
    knowledge_base_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the knowledge base to get the upload URL for"""

    filename: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""The filename of the file to upload"""
