"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class AudioTypedDict(TypedDict):
    id: str


class Audio(BaseModel):
    id: str
