"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateKnowledgeBaseRequestTypedDict(TypedDict):
    name: str
    embedding_model: NotRequired[str]
    r"""The embedding model to use for the knowledge base"""


class CreateKnowledgeBaseRequest(BaseModel):
    name: str

    embedding_model: Optional[str] = "azure/text-embedding-3-large"
    r"""The embedding model to use for the knowledge base"""
