"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcompletionnonstreaming import (
    ChatCompletionNonStreaming,
    ChatCompletionNonStreamingTypedDict,
)
from .chatcompletionstreaming import (
    ChatCompletionStreaming,
    ChatCompletionStreamingTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


PayloadTypedDict = TypeAliasType(
    "PayloadTypedDict",
    Union[ChatCompletionNonStreamingTypedDict, ChatCompletionStreamingTypedDict],
)


Payload = TypeAliasType(
    "Payload", Union[ChatCompletionNonStreaming, ChatCompletionStreaming]
)
