"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class QueryKnowledgeBaseResponseTypedDict(TypedDict):
    id: str
    r"""The id of the document"""
    key: str
    r"""The key of the document"""
    content: str
    r"""The content of the document"""
    metadata: Dict[str, Any]
    r"""The metadata of the document"""
    score: float
    r"""The score of the document"""


class QueryKnowledgeBaseResponse(BaseModel):
    id: str
    r"""The id of the document"""

    key: str
    r"""The key of the document"""

    content: str
    r"""The content of the document"""

    metadata: Dict[str, Any]
    r"""The metadata of the document"""

    score: float
    r"""The score of the document"""
