"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class RerankCostTypedDict(TypedDict):
    r"""Cost information for reranking."""

    generation: float
    r"""Cost of the reranking request in USD"""
    platform: float
    r"""Platform fee in USD (percentage of generation cost)"""
    total: float
    r"""Total cost in USD (generation + platform)"""


class RerankCost(BaseModel):
    r"""Cost information for reranking."""

    generation: float
    r"""Cost of the reranking request in USD"""

    platform: float
    r"""Platform fee in USD (percentage of generation cost)"""

    total: float
    r"""Total cost in USD (generation + platform)"""
