"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatedatasetentryrequest import (
    UpdateDatasetEntryRequest,
    UpdateDatasetEntryRequestTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequestTypedDict(TypedDict):
    dataset_id: str
    r"""The id of the dataset"""
    entry_id: str
    r"""The id of the entry to update"""
    update_dataset_entry_request: UpdateDatasetEntryRequestTypedDict


class UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the dataset"""

    entry_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the entry to update"""

    update_dataset_entry_request: Annotated[
        UpdateDatasetEntryRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
