"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing_extensions import TypedDict


class OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunctionTypedDict(
    TypedDict
):
    arguments: str
    name: str


class OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunction(BaseModel):
    arguments: str

    name: str
