"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Op(str, Enum):
    EQUAL_ = "="
    NOT_EQUAL_ = "!="
    GREATER_THAN_ = ">"
    LESS_THAN_ = "<"
    IN = "in"
