"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .functiondefinition import FunctionDefinition, FunctionDefinitionTypedDict
from opperai.types import BaseModel
from opperai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ChatCompletionFunctionToolParamTypedDict(TypedDict):
    function: FunctionDefinitionTypedDict
    type: Literal["function"]


class ChatCompletionFunctionToolParam(BaseModel):
    function: FunctionDefinition

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
